@@ -1,3 +1,6 @@
+## ----echo=FALSE----------------------------------------------------------
+library(ontologyIndex)
+
 ## ----eval=FALSE----------------------------------------------------------
 #  ontology <- get_ontology(file)
 
